# pythermiagenesis
A python library for Thermia Inverter/Mega heatpumps

This library communicates with the device using Modbus TCP.
Set BMC to Modbus TCP on your heat pump to enable communication through this library.
